HypersyncLog

Type Alias HypersyncLog 

pub type HypersyncLog = Log;
Type alias for HyperSync log entries.

Aliased Type

pub struct HypersyncLog {
    pub removed: Option<bool>,
    pub log_index: Option<UInt>,
    pub transaction_index: Option<UInt>,
    pub transaction_hash: Option<FixedSizeData<32>>,
    pub block_hash: Option<FixedSizeData<32>>,
    pub block_number: Option<UInt>,
    pub address: Option<FixedSizeData<20>>,
    pub data: Option<Data>,
    pub topics: ArrayVec<Option<FixedSizeData<32>>, 4>,
}

Fields

removed: Option<bool>

The boolean value indicating if the event was removed from the blockchain due to a chain reorganization. True if the log was removed. False if it is a valid log.

log_index: Option<UInt>

The integer identifying the index of the event within the block’s list of events.

transaction_index: Option<UInt>

The integer index of the transaction within the block’s list of transactions.

transaction_hash: Option<FixedSizeData<32>>

The hash of the transaction that triggered the event.

block_hash: Option<FixedSizeData<32>>

The hash of the block in which the event was included.

block_number: Option<UInt>

The block number in which the event was included.

address: Option<FixedSizeData<20>>

The contract address from which the event originated.

data: Option<Data>

The non-indexed data that was emitted along with the event.

topics: ArrayVec<Option<FixedSizeData<32>>, 4>

An array of 32-byte data fields containing indexed event parameters.